========
Filtrark
========


.. image:: https://img.shields.io/pypi/v/filtrark.svg
        :target: https://pypi.python.org/pypi/filtrark

.. image:: https://img.shields.io/travis/nubark/filtrark.svg
        :target: https://travis-ci.org/nubark/filtrark

.. image:: https://readthedocs.org/projects/filtrark/badge/?version=latest
        :target: https://filtrark.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Build filter clauses from instruction lists


* Free software: MIT license
* Documentation: https://filtrark.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
